@@ -10,7 +10,7 @@ class Middleware:
         
         response = self.app.handle_request(request)
         
-        return await response(scope, receive, send)
+        await response(scope, receive, send)
 
     def add(self, middleware_cls):
         self.app = middleware_cls(self.app)
